@@ -185,7 +185,9 @@ typedef struct AstFitsChan {
    double fitstol;  /* Max departure from linearity, in pixels */
    int iwc;         /* Include an IWC Frame? */
    int clean;       /* Remove used cards even if an error occurs? */
+   int altaxes;     /* Controls creation of FITS-WCS alternate axes */
    int fitsdigits;  /* No. of decmial places in formatted floating point keyword values */
+   int fitsrounding;  /* No. of decmial places guarded against rounding in formatted floating point keyword values */
    char *fitsaxisorder; /* Pointer to a string defining WCS axis order */
    char *warnings;  /* Pointer to a string containing warning conditions */
    void *card;      /* Pointer to next FitsCard to be read */
@@ -276,6 +278,16 @@ typedef struct AstFitsChanVtab {
    void (* SetFitsDigits)( AstFitsChan *, int, int * );
    void (* ClearFitsDigits)( AstFitsChan *, int * );
 
+   int (* GetFitsRounding)( AstFitsChan *, int * );
+   int (* TestFitsRounding)( AstFitsChan *, int * );
+   void (* SetFitsRounding)( AstFitsChan *, int, int * );
+   void (* ClearFitsRounding)( AstFitsChan *, int * );
+
+   int (* GetAltAxes)( AstFitsChan *, int * );
+   int (* TestAltAxes)( AstFitsChan *, int * );
+   void (* SetAltAxes)( AstFitsChan *, int, int * );
+   void (* ClearAltAxes)( AstFitsChan *, int * );
+
    const char *(* GetFitsAxisOrder)( AstFitsChan *, int * );
    int (* TestFitsAxisOrder)( AstFitsChan *, int * );
    void (* SetFitsAxisOrder)( AstFitsChan *, const char *, int * );
@@ -575,6 +587,16 @@ void astInitFitsChanGlobals_( AstFitsChanGlobals * );
    void astSetFitsDigits_( AstFitsChan *, int, int * );
    void astClearFitsDigits_( AstFitsChan *, int * );
 
+   int astGetFitsRounding_( AstFitsChan *, int * );
+   int astTestFitsRounding_( AstFitsChan *, int * );
+   void astSetFitsRounding_( AstFitsChan *, int, int * );
+   void astClearFitsRounding_( AstFitsChan *, int * );
+
+   int astGetAltAxes_( AstFitsChan *, int * );
+   int astTestAltAxes_( AstFitsChan *, int * );
+   void astSetAltAxes_( AstFitsChan *, int, int * );
+   void astClearAltAxes_( AstFitsChan *, int * );
+
    const char *astGetFitsAxisOrder_( AstFitsChan *, int * );
    int astTestFitsAxisOrder_( AstFitsChan *, int * );
    void astSetFitsAxisOrder_( AstFitsChan *, const char *, int * );
@@ -889,6 +911,24 @@ astINVOKE(V,astSetFitsDigits_(astCheckFitsChan(this),fitsdigits,STATUS_PTR))
 #define astTestFitsDigits(this) \
 astINVOKE(V,astTestFitsDigits_(astCheckFitsChan(this),STATUS_PTR))
 
+#define astClearFitsRounding(this) \
+astINVOKE(V,astClearFitsRounding_(astCheckFitsChan(this),STATUS_PTR))
+#define astGetFitsRounding(this) \
+astINVOKE(V,astGetFitsRounding_(astCheckFitsChan(this),STATUS_PTR))
+#define astSetFitsRounding(this,fitsrounding) \
+astINVOKE(V,astSetFitsRounding_(astCheckFitsChan(this),fitsrounding,STATUS_PTR))
+#define astTestFitsRounding(this) \
+astINVOKE(V,astTestFitsRounding_(astCheckFitsChan(this),STATUS_PTR))
+
+#define astClearAltAxes(this) \
+astINVOKE(V,astClearAltAxes_(astCheckFitsChan(this),STATUS_PTR))
+#define astGetAltAxes(this) \
+astINVOKE(V,astGetAltAxes_(astCheckFitsChan(this),STATUS_PTR))
+#define astSetAltAxes(this,altaxes) \
+astINVOKE(V,astSetAltAxes_(astCheckFitsChan(this),altaxes,STATUS_PTR))
+#define astTestAltAxes(this) \
+astINVOKE(V,astTestAltAxes_(astCheckFitsChan(this),STATUS_PTR))
+
 #define astClearFitsAxisOrder(this) \
 astINVOKE(V,astClearFitsAxisOrder_(astCheckFitsChan(this),STATUS_PTR))
 #define astGetFitsAxisOrder(this) \
